@@ -5,7 +5,7 @@ from telegram.ext import (CommandHandler, Filters, MessageHandler,
 
 from digitalguide import rasa_filter, uhrzeit_filter
 from digitalguide.pattern import (EMOJI_PATTERN, JA_PATTERN, NEIN_PATTERN,
-                                  WEITER_PATTERN, WOHIN_PATTERN)
+                                  WEITER_PATTERN, WOHIN_PATTERN, ZURUECK_PATTERN)
 
 
 def read_state_yml(filename, actions=None, prechecks: list = None):
@@ -38,6 +38,9 @@ def read_state_yml(filename, actions=None, prechecks: list = None):
                     elif handler["regex"] == "NEIN_PATTERN":
                         newHandler = MessageHandler(Filters.regex(
                             NEIN_PATTERN), actions[handler["action"]])
+                    elif handler["regex"] == "ZURUECK_PATTERN":
+                        newHandler = MessageHandler(Filters.regex(
+                            ZURUECK_PATTERN), actions[handler["action"]])
                     else:
                         newHandler = MessageHandler(Filters.regex(
                             handler["regex"]), actions[handler["action"]])
