@@ -31,10 +31,15 @@ def generate_gif(im1, im2):
     return bio
 
 
-def overlay_images(background, foreground, x_position="left", y_position="up", resize=True):
-    if resize:
-        foreground = background.resize(
-            (round(foreground.size[0]), round(foreground.size[1])))
+def overlay_images(background, foreground, x_position="left", y_position="up", resize="x"):
+    if resize=="x":
+        scale_ratio = foreground.size[0]/background.size[0]
+        background = background.resize(
+            (round(foreground.size[0]), round(foreground.size[1]*scale_ratio)))
+    elif resize=="y":
+        scale_ratio = foreground.size[1]/background.size[1]
+        background = background.resize(
+            (round(foreground.size[0]*scale_ratio), round(foreground.size[1])))
     
     if x_position=="left":
         x_coordinate = 0
@@ -58,14 +63,17 @@ def overlay_images(background, foreground, x_position="left", y_position="up", r
     bio.seek(0)
     return bio
 
-def telegram_eval_image_overlay(update: Update, context: CallbackContext, picture):
+def telegram_eval_image_overlay(update: Update, context: CallbackContext, picture, x_position="left", y_position="up", resize="x"):
+    if resize in ["False", "false"]:
+        resize = False
+
     im_bytes = update.message.photo[-1].get_file().download_as_bytearray()
 
     im_file = BytesIO(im_bytes)  # convert image to file-like object
     im1 = Image.open(im_file)   # img is now PIL Image object
     im2 = Image.open('assets/' + picture)
 
-    new_im = overlay_images(im1, im2)
+    new_im = overlay_images(im1, im2, x_position,y_position, resize)
 
     update.message.reply_photo(new_im)
 
