@@ -112,8 +112,10 @@ def telegram_eval_kommazahl(update: Update, context: CallbackContext, echter_wer
     match = re.search(
         r"(?P<vorkomma>\d{1,2}),? ?(?P<nachkomma>\d{,2})", update.message.text)
 
-    schaetzung = int(match.group('vorkomma')) + \
-        float("0."+match.group('nachkomma'))
+    schaetzung = int(match.group('vorkomma'))
+
+    if match.group('nachkomma'):
+        schaetzung += float("0."+match.group('nachkomma'))
 
     if schaetzung == echter_wert:
         update.message.reply_text(richtig_text,
@@ -137,10 +139,12 @@ def whatsapp_eval_kommazahl(client, update: WhatsAppUpdate, context, echter_wert
     echter_wert = float(echter_wert)
     import re
     match = re.search(
-        r"(?P<vorkomma>\d{1,2}),? ?(?P<nachkomma>\d{,2})", update.Body)
+        r"(?P<vorkomma>\d{1,}),? ?(?P<nachkomma>\d{,2})", update.Body)
 
-    schaetzung = int(match.group('vorkomma')) + \
-        float("0."+match.group('nachkomma'))
+    schaetzung = int(match.group('vorkomma'))
+
+    if match.group('nachkomma'):
+        schaetzung += float("0."+match.group('nachkomma'))
 
     if schaetzung == echter_wert:
         client.messages.create(
@@ -157,7 +161,7 @@ def whatsapp_eval_kommazahl(client, update: WhatsAppUpdate, context, echter_wert
             to=update.From
         )
 
-    elif differenz < -1:
+    elif differenz < -1 or (-1 < differenz < 0):
         client.messages.create(
             body=spaeter_plural_text.format(abs(differenz)),
             from_=update.To,
@@ -171,7 +175,83 @@ def whatsapp_eval_kommazahl(client, update: WhatsAppUpdate, context, echter_wert
             to=update.From
         )
 
-    elif differenz > 1:
+    elif differenz > 1 or (0 < differenz < 1):
+        client.messages.create(
+            body=vorher_plural_text.format(abs(differenz)),
+            from_=update.To,
+            to=update.From
+        )
+
+def telegram_eval_laenge(update: Update, context: CallbackContext, echter_wert, richtig_text, vorher_singular_text, vorher_plural_text, spaeter_singular_text, spaeter_plural_text):
+    echter_wert = float(echter_wert)
+    import re
+    match = re.search(
+        r"(?P<cm>(?P<cm_zahl>\d{1,}),?(?P<cm_komma>\d{1,})? ?(cm|CM|Cm))", update.message.text)
+
+    schaetzung = int(match.group('cm_zahl')) 
+    
+    if match.group('cm_komma'):
+        schaetzung += float("0."+match.group('cm_komma'))
+
+    if schaetzung == echter_wert:
+        update.message.reply_text(richtig_text,
+                                  reply_markup=ReplyKeyboardRemove())
+    
+    differenz = schaetzung - echter_wert
+    if differenz == -1:
+        update.message.reply_text(spaeter_singular_text,
+                                  reply_markup=ReplyKeyboardRemove())
+    elif differenz < -1 or (-1 < differenz < 0):
+        update.message.reply_text(spaeter_plural_text.format(abs(differenz)),
+                                  reply_markup=ReplyKeyboardRemove())
+    elif differenz == 1:
+        update.message.reply_text(vorher_singular_text,
+                                  reply_markup=ReplyKeyboardRemove())
+    elif differenz > 1 or (0 < differenz < 1):
+        update.message.reply_text(vorher_plural_text.format(abs(differenz)),
+                                  reply_markup=ReplyKeyboardRemove())
+
+def whatsapp_eval_laenge(client, update: WhatsAppUpdate, context, echter_wert, richtig_text, vorher_singular_text, vorher_plural_text, spaeter_singular_text, spaeter_plural_text):
+    echter_wert = float(echter_wert)
+    import re
+    match = re.search(
+       r"(?P<cm>(?P<cm_zahl>\d{1,}),?(?P<cm_komma>\d{1,})? ?(cm|CM|Cm))", update.Body)
+
+    schaetzung = int(match.group('cm_zahl'))
+
+    if match.group('cm_komma'):
+        schaetzung += float("0."+match.group('cm_komma'))
+
+    if schaetzung == echter_wert:
+        client.messages.create(
+            body=richtig_text,
+            from_=update.To,
+            to=update.From
+        )
+
+    differenz = schaetzung - echter_wert
+    if differenz == -1:
+        client.messages.create(
+            body=spaeter_singular_text,
+            from_=update.To,
+            to=update.From
+        )
+
+    elif differenz < -1 or (-1 < differenz < 0):
+        client.messages.create(
+            body=spaeter_plural_text.format(abs(differenz)),
+            from_=update.To,
+            to=update.From
+        )
+
+    elif differenz == 1:
+        client.messages.create(
+            body=vorher_singular_text,
+            from_=update.To,
+            to=update.From
+        )
+
+    elif differenz > 1 or (0 < differenz < 1):
         client.messages.create(
             body=vorher_plural_text.format(abs(differenz)),
             from_=update.To,
@@ -182,9 +262,11 @@ def whatsapp_eval_kommazahl(client, update: WhatsAppUpdate, context, echter_wert
 telegram_action_functions = {"eval_jahreszahl": telegram_eval_jahreszahl,
                              "eval_prozentzahl": telegram_eval_prozentzahl,
                              "eval_kommazahl": telegram_eval_kommazahl,
+                             "eval_laenge": telegram_eval_laenge,
                              }
 
 whatsapp_action_functions = {"eval_jahreszahl": whatsapp_eval_jahreszahl,
                              "eval_prozentzahl": whatsapp_eval_prozentzahl,
                              "eval_kommazahl": whatsapp_eval_kommazahl,
+                             "eval_laenge": whatsapp_eval_laenge,
                              }
