@@ -100,7 +100,7 @@ class Interaktion:
                     "action": "{}_tipp".format(poi_name)}]
 
             states["{}_AUFLOESUNG".format(poi_name.upper())] = readTriggers([("Liste", "Weiter")], next_interaktion) \
-                + readTriggers([("Liste", "zurück")], "{}_frage".format(poi_name)) \
+                + readTriggers([("Liste", "Zurueck")], "{}_frage".format(poi_name)) \
                 + [{"handler": "TypeHandler", "type": "Update", "action": "weiter_tipp"}]
 
         elif interaction_typ == "Schätzfrage":
@@ -128,6 +128,11 @@ class Interaktion:
                     + [{"handler": "TypeHandler", "type": "Update",
                         "action": "{}_tipp".format(poi_name)}]
 
+            elif interaktion_dict["Typ"][0][0] == "Länge":
+                states["{}_FRAGE".format(poi_name.upper())] = (readTriggers([("Regex", "(?P<cm>(?P<cm_zahl>\d{1,}),?(?P<cm_komma>\d{1,})? ?(cm|CM|Cm))")], "{}_aufloesung".format(poi_name))) \
+                    + [{"handler": "TypeHandler", "type": "Update",
+                        "action": "{}_tipp".format(poi_name)}]
+
             elif interaktion_dict["Typ"][0][0] == "Römische Jahreszahl":
                 states["{}_FRAGE".format(poi_name.upper())] = (readTriggers([("Regex", "^M{0,3}(CM|CD|D?C{0,3})(XC|XL|L?X{0,3})(IX|IV|V?I{0,3})$")], "{}_aufloesung".format(poi_name))) \
                     + [{"handler": "TypeHandler", "type": "Update",
@@ -151,11 +156,17 @@ class Interaktion:
                         + readActions([("Formel", "function: append_to_context\nkey: {}\nvalue: {}".format(poi_name, aktion.replace("antwort_", "")))], messanger=messanger, asset_url=asset_url)\
                         + readActions(aktion_list, messanger=messanger, asset_url=asset_url) \
                         + readActions(interaktion_dict["richtig Antwort"], messanger=messanger, asset_url=asset_url)
+                    
+                    actions["{}_{}_re".format(poi_name, aktion)] = readActions(aktion_list, messanger=messanger, asset_url=asset_url) \
+                                                                        + readActions(interaktion_dict["richtig Antwort"], messanger=messanger, asset_url=asset_url)
 
                 elif aktion.startswith("trigger_"):
                     states["{}_FRAGE".format(poi_name.upper())] += readTriggers(
                         aktion_list, "{}_{}".format(poi_name, aktion.replace("trigger_", "antwort_")))
 
+                    states["{}_AUFLOESUNG".format(poi_name.upper())] += readTriggers(
+                        aktion_list, "{}_{}_re".format(poi_name, aktion.replace("trigger_", "antwort_")))
+
                 elif aktion.startswith("name_"):
                     answer_id_name_list.append(
                         [aktion.replace("name_", ""), aktion_list[0][1]])
@@ -171,8 +182,9 @@ class Interaktion:
                 + [{"handler": "TypeHandler", "type": "Update",
                     "action": "{}_falsche_antwort".format(poi_name)}]
 
-            states["{}_AUFLOESUNG".format(poi_name.upper())] = readTriggers([("Liste", "Weiter")], next_interaktion) \
+            states["{}_AUFLOESUNG".format(poi_name.upper())] += readTriggers([("Liste", "Weiter")], next_interaktion) \
                 + [{"handler": "TypeHandler", "type": "Update", "action": "weiter_tipp"}]
+
         elif interaction_typ == "Beteiligungsfrage":
             actions["{}_frage".format(poi_name)] = readActions(
                 interaktion_dict["Frage"] + [("Return", "{}_FRAGE".format(poi_name.upper()))], messanger=messanger, asset_url=asset_url)
