@@ -19,6 +19,8 @@ def readTriggers(format_inhalt_list, action):
                 trigger_dict["regex"] = "WOHIN_PATTERN"
             elif inhalt == "Nein":
                 trigger_dict["regex"] = "NEIN_PATTERN"
+            elif inhalt == "Zurueck":
+                trigger_dict["regex"] = "ZURUECK_PATTERN"
             else:
                 trigger_dict["regex"] = inhalt
                 print("List {} ist nicht bekannt!".format(inhalt))
